<?php

class PayshopCommons
{
    /**
     * Check Payshop response
     *
     * @param array $response
     * @return void
     * @throws Exception
     */
    public static function checkResponse($response)
    {
        if ($response['status'] == 201) {
            return true;
        }

        if ($response['status'] == 401 || $response['status'] == 403) {
            $message = __('Invalid API credentials. Check your credentials in the module settings.', 'payshop');

            PayshopLog::generate($message, 'error');

            throw new Exception($message);
        }

        $body = $response['response'];

        if (isset($body['parameters']['number'])) {
            throw new Exception(__('Invalid card number', 'payshop'));
        }

        $message = isset($body['message']) ? $body['message'] : $body;
        $message = $message == 'Transaction Error' ? 
                    __('Transaction error, check your payment informations', 'payshop') : 
                    $message;

        throw new Exception($message);
    }

    /**
     * Get date limit to confirm payment
     *
     * @param WC_Order $order
     * @return string
     */
    public static function getDateLimitToConfirmPayment($order)
    {
        $createOrderDate = $order->get_date_created();

        $limiteToConfirmPayment = new DateTime($createOrderDate->format('Y-m-d H:i'));
        
        $daystoConfirmPayment = 'P7D';
        $limiteToConfirmPayment->add(new DateInterval($daystoConfirmPayment));

        return $limiteToConfirmPayment;
    }


    /**
     * Save order references on meta
     *
     * @param WC_Order $order
     * @param array $references
     * @return void
     */
    public static function saveOrderReference($order, $references)
    {
        foreach($references as $reference) {
            $order->update_meta_data(
                '_payshop_' . $reference['field'],
                $reference['value'],
                true
            );
        }

        $order->save();
    }
}