<?php

require_once 'PayshopMBWayDeclined.php';
require_once 'PayshopPaymentSuccess.php';

 class PayshopProcessEvent
 {
    /**
     * @var PayshopPaymentSuccess
     */
    private $payshopPaymentSuccess;

    /**
     * @var PayshopMbWayDeclined
     */
    private $payshopMbWayDeclined;

    /**
     * Class constructor
     */
    public function __construct()
    {
        $this->payshopPaymentSuccess = new PayshopPaymentSuccess();
        $this->payshopMbWayDeclined = new PayshopMBWayDeclined();
    }

    /**
     * Process webhook events
     *
     * @param array $eventBasicInformation
     * @return void
     */
    public function execute($eventBasicInformation)
    {
        $eventReponse = $this->getApiEvent($eventBasicInformation['event']);

        $event = $eventReponse['response'];

        $order = $this->getOrderByChargeId($event['charge']['id']);

        if ($event['type'] == 'payment.success') {
            return $this->payshopPaymentSuccess->process($order);
        }

        if ($this->isWBWay($event) || $this->isDeclined($event)) {
            return $this->payshopMbWayDeclined->process($order);
        }
    }

    /**
     * Get the event from the API
     *
     * @param string $eventId
     * @return array
     */
    private function getApiEvent($eventId)
    {
        $payshopSDK = PayshopClientFactory::getInstance();
        $eventReponse = $payshopSDK->getEvent($eventId);

        $this->checkEventReponse($eventReponse);

        return $eventReponse;
    }

    /**
     * Get order by charge id
     *
     * @param string $chargeId
     * @return WC_Order
     */
    private function getOrderByChargeId($chargeId)
    {
        //get order by meta on woocommerce
        $order = new WP_Query([
            'post_type' => 'shop_order',
            'post_status' => 'any',
            'meta_key' => '_payshop_charge_id',
            'meta_value' => $chargeId,
            'posts_per_page' => 1
        ]);

        $order = wc_get_order($order->posts[0]->ID);

        return $order;
    }

    /**
     * Check the event response
     *
     * @param array $response
     * @return void
     * @throws Exception
     */
    private function checkEventReponse($response)
    {
        if ($response['status'] != '200') {
            throw new Exception("Get event on payshop api error");
        }
    }

    /**
     * Check if event is  WBWay
     *
     * @param array $event
     * @return bool
     */
    private function isWBWay($event)
    {
        return $event['charge']['charge_type'] == "mbway";
    }

    /**
     * Check if event is  declined
     *
     * @param array $event
     * @return bool
     */
    private function isDeclined($event)
    {
        return $event['instrument']['failure_code'] == "03.00.0000";
    }
 }